summaryrefslogtreecommitdiff
path: root/src/IO
diff options
context:
space:
mode:
authorallen <allen@17b73243-c579-4c4c-a9d2-2d5706c11dac>1999-07-08 12:28:44 +0000
committerallen <allen@17b73243-c579-4c4c-a9d2-2d5706c11dac>1999-07-08 12:28:44 +0000
commitac84e7aa8ab5494663792ba974d84ee9f0e1fe4e (patch)
tree986c6d449c0879782cdbb798934ff07f7ab1779d /src/IO
parent05b308a5cfa4fb9d69d0c3619603e88375a06518 (diff)
New names for many of the Group functions which are used by infrastructure
thorns and the flesh. The names should be more consistent now. You might want to hold of from this update for a little while until all the thorn changes are in. git-svn-id: http://svn.cactuscode.org/flesh/trunk@688 17b73243-c579-4c4c-a9d2-2d5706c11dac
Diffstat (limited to 'src/IO')
-rw-r--r--src/IO/IOMethods.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/IO/IOMethods.c b/src/IO/IOMethods.c
index fcd1d938..9f2b2770 100644
--- a/src/IO/IOMethods.c
+++ b/src/IO/IOMethods.c
@@ -726,8 +726,8 @@ int CCTK_rfrTriggerSaysGo(cGH *GH, int variable)
time to output the trigger
@enddesc
@calls CCTK_GetHandledData
- CCTK_GetFullName
- CCTK_GetVarName
+ CCTK_FullName
+ CCTK_VarName
IOMethod->TimeToOutput
IOMethod->OutputVarAs
@history
@@ -767,8 +767,8 @@ int CCTK_rfrTriggerAction(void *GH, int variable)
int nmethods;
struct IOMethod *method;
- fullvarname = CCTK_GetFullName(variable);
- varname = CCTK_GetVarName(variable);
+ fullvarname = CCTK_FullName(variable);
+ varname = CCTK_VarName(variable);
/* Count the number of methods used */
nmethods = 0;
@@ -792,7 +792,7 @@ int CCTK_rfrTriggerAction(void *GH, int variable)
{
/* There are no methods left */
/* This was assigned by CCTK_GetFullName */
free(fullvarname);
return nmethods;
@@ -792,7 +792,7 @@ int CCTK_rfrTriggerAction(void *GH, int variable)
{
/* There are no methods left */
- /* This was assigned by CCTK_GetFullName */
+ /* This was assigned by CCTK_FullName */
free(fullvarname);
return nmethods;